@@ -1,6 +1,5 @@
 import logging
 from typing import Any
-from typing import Dict
 
 from pythogen import models
 from pythogen.parsers.parameters import ParameterParser
@@ -29,10 +28,20 @@ class OperationParser:
         self._parameters_parser = parameters_parser
 
     def parse_item(
-        self, path_str: str, method: models.HttpMethod, operation_data: Dict[str, Any]
+        self, path_str: str, method: models.HttpMethod, operation_data: dict[str, Any]
     ) -> models.OperationObject:
         """Спарсить спецификацию метода ручки (POST-, GET-, PUT-запроса и т.п.)"""
-        responses: Dict[str, models.ResponseObject] = {}
+        responses: dict[str, models.ResponseObject] = {}
+
+        operation_id: str = operation_data.get('operationId', '')
+        if not operation_id:
+            operation_id = (
+                path_str.removeprefix('/').replace('-', '_').replace('/', '_').replace('{', '').replace('}', '')
+            )
+            operation_id = method.value + '_' + operation_id
+            operation_id = operation_id.lower()
+        else:
+            operation_id = operation_id.replace('_', ' ').title().replace(' ', '')
 
         for status_code, response_data in operation_data['responses'].items():
             if status_code == 'default':
@@ -44,13 +53,14 @@ class OperationParser:
                 response_data = resolved_ref.ref_data
                 response_id = resolved_ref.ref_id
             else:
-                response_id = f"{operation_data['summary'].replace(' ', '')}Response{status_code}"
+
+                response_id = f"{operation_id}Response{status_code}"
 
             responses[status_code] = self._response_parser.parse_item(response_id, response_data)
 
         request_body_data = operation_data.get('requestBody')
         if request_body_data:
-            request_body = self._request_body_parser.parse_item(request_body_data, operation_data)
+            request_body = self._request_body_parser.parse_item(request_body_data, operation_id)
         else:
             request_body = None
 
