@@ -1,17 +1,17 @@
+import logging
 import re
 from collections import defaultdict
 from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Union
 
 from pythogen import models
 from pythogen.parsers.inline_schemas_aggregator import InlineSchemasAggregator
 from pythogen.parsers.references import RefResolver
 
 
-PRIMITIVE_TYPES = ('string', 'number', 'integer', 'boolean')
+logger = logging.getLogger(__name__)
+
+
+PRIMITIVE_TYPES = ('string', 'number', 'integer', 'boolean', 'null')
 
 
 class SchemaParser:
@@ -43,8 +43,8 @@ class SchemaParser:
     def __init__(
         self,
         ref_resolver: RefResolver,
-        openapi_data: Dict[str, Any],
-        discriminator_base_class_schemas: List[models.DiscriminatorBaseClassSchema],
+        openapi_data: dict[str, Any],
+        discriminator_base_class_schemas: list[models.DiscriminatorBaseClassSchema],
         inline_schema_aggregator: InlineSchemasAggregator,
     ) -> None:
         self._openapi_data = openapi_data
@@ -52,12 +52,11 @@ class SchemaParser:
         self._discriminator_base_class_schemas = discriminator_base_class_schemas
         self._inline_schema_aggregator = inline_schema_aggregator
 
-        self._schema_ids = list(self._openapi_data["components"].get('schemas', {}))
         self._processiong_parsed_schema_id_count: dict[str, int] = defaultdict(int)
+        self._schemas: dict[str, models.SchemaObject] = {}
 
-    def parse_collection(self) -> Dict[str, models.SchemaObject]:
-        schemas_data = self._openapi_data["components"].get('schemas', {})
-        schemas = {}
+    def parse_collection(self) -> dict[str, models.SchemaObject]:
+        schemas_data = self._openapi_data.get('components', {}).get('schemas', {})
         for schema_id, schema_data in schemas_data.items():
             if schema_data.get('$ref', None):
                 resolved_ref = self._ref_resolver.resolve(schema_data['$ref'])
@@ -66,12 +65,12 @@ class SchemaParser:
                 schema = self.parse_item(schema_id, schema_data)
 
             if not schema.is_fake:
-                schemas[schema_id] = schema
+                self._schemas[schema_id] = schema
 
-        return schemas
+        return self._schemas
 
     def parse_item(
-        self, schema_id: str, schema_data: Dict[str, Any], from_depth_level: bool = False
+        self, schema_id: str, schema_data: dict[str, Any], from_depth_level: bool = False
     ) -> models.SchemaObject:
         """Спарсить схему из OpenAPI-спеки
 
@@ -85,7 +84,11 @@ class SchemaParser:
             Флаг, указывающий, что схема была спарсена внутри другой схемы.
             Используется для разрешения циклических схем.
         """
+        if schema_id in self._schemas:
+            return self._schemas[schema_id]
+
         schema_type = self._parse_type(schema_data)
+        all_of = self._parse_all_of(schema_id, schema_data)
 
         self._processiong_parsed_schema_id_count[schema_id] += 1
         if self._processiong_parsed_schema_id_count[schema_id] > 1 and from_depth_level:
@@ -110,6 +113,7 @@ class SchemaParser:
                 properties=[],
                 description=self._get_description(schema_data),
                 is_fake=True,
+                all_of=all_of,
             )
 
         discr_schema = self._get_discriminator_base_class_schema(schema_data)
@@ -126,9 +130,25 @@ class SchemaParser:
             items=self._parse_items(schema_id, schema_data),
             properties=self._parse_properties(schema_type, schema_data),
             description=self._get_description(schema_data),
+            all_of=all_of,
         )
 
-    def _parse_type(self, data: Dict[str, Any]) -> models.Type:
+    def _parse_all_of(self, parent_id: str, parent_data: dict[str, Any]) -> list[models.SchemaObject]:
+        result: list[models.SchemaObject] = []
+        for all_of_item_num, all_of_item in enumerate(parent_data.get("allOf", [])):
+            if ref := all_of_item.get('$ref'):
+                resolved_ref = self._ref_resolver.resolve(ref)
+                all_of_item_schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data)
+                result.append(all_of_item_schema)
+            else:
+                all_of_item_schema_id = f"{parent_id}_item_{all_of_item_num}"
+                all_of_item_schema = self.parse_item(all_of_item_schema_id, all_of_item)
+                self._inline_schema_aggregator.add(all_of_item_schema_id, all_of_item_schema)
+                result.append(all_of_item_schema)
+
+        return result
+
+    def _parse_type(self, data: dict[str, Any]) -> models.Type:
         if data == {}:
             # Парсинг пустой схемы
             # application/json:
@@ -139,24 +159,26 @@ class SchemaParser:
             data_type = models.Type.object
         elif 'anyOf' in data:
             data_type = models.Type.any_of
+        elif 'type' not in data:
+            data_type = models.Type.object
         else:
-            raw_data_type: Optional[str] = data.get('type')
+            raw_data_type: str | None = data.get('type')
             try:
                 data_type = models.Type(raw_data_type)
             except ValueError:
                 raise Exception(f'Unable to parse schema "{id}", unknown type "{raw_data_type}" on "{data}"')
         return data_type
 
-    def _parse_format(self, data: Dict[str, Any]) -> Optional[models.Format]:
+    def _parse_format(self, data: dict[str, Any]) -> models.Format | None:
         data_format = data.get('format')
         if data_format:
             try:
-                return models.Format[data_format.replace('-', '_')]
+                return models.Format(data_format)
             except Exception:
                 raise Exception(f'Unable to parse schema "{id}", unknown format "{data_format}"')
         return None
 
-    def _get_description(self, data: Dict[str, Any]) -> Optional[str]:
+    def _get_description(self, data: dict[str, Any]) -> str | None:
         description = data.get("description", "")
         if description:
             description = description.replace("\n", "\\n")
@@ -166,8 +188,8 @@ class SchemaParser:
 
     def _get_discriminator_base_class_schema(
         self,
-        data: Dict[str, Any],
-    ) -> Optional[models.DiscriminatorBaseClassSchema]:
+        data: dict[str, Any],
+    ) -> models.DiscriminatorBaseClassSchema | None:
         description = data.get("description", "")
         if "__discriminator__" not in description:
             return None
@@ -181,12 +203,12 @@ class SchemaParser:
     def _parse_properties(
         self,
         schema_type: models.Type,
-        data: Dict[str, Any],
-    ) -> List[models.SchemaProperty]:
+        data: dict[str, Any],
+    ) -> list[models.SchemaProperty]:
         data_format = data.get('format')
         if data_format:
             try:
-                data_format = models.Format[data_format.replace('-', '_')]
+                data_format = models.Format(data_format)
             except Exception:
                 raise Exception(f'Unable to parse schema "{id}", unknown format "{data_format}"')
 
@@ -212,18 +234,7 @@ class SchemaParser:
                     elif 'allOf' in property_schema_data:
                         property_schema_id = key + "_ref_obj"
                         schema = self.parse_item(property_schema_id, property_schema_data)
-
-                        for all_of_reference_container in property_schema_data['allOf']:
-                            ref = all_of_reference_container['$ref']
-                            all_of_resolved_ref = self._ref_resolver.resolve(ref)
-                            all_of_reference_parsed_schema = self.parse_item(
-                                schema_id=all_of_resolved_ref.ref_id,
-                                schema_data=all_of_resolved_ref.ref_data,
-                            )
-                            schema.properties += all_of_reference_parsed_schema.properties
-
                         self._inline_schema_aggregator.add(property_schema_id, schema)
-
                     elif property_schema_data.get('type') == models.Type.array.value:
                         # specify inline array name
                         property_schema_id = key + "_list"
@@ -307,8 +318,8 @@ class SchemaParser:
     def _parse_items(
         self,
         parent_schema_id: str,
-        data: Dict[str, Any],
-    ) -> Union[Optional[models.SchemaObject], List[models.SchemaObject]]:
+        data: dict[str, Any],
+    ) -> models.SchemaObject | list[models.SchemaObject] | None:
         items_schema_data = data.get('items')
         if items_schema_data:
             if items_schema_data.get('$ref', None):
@@ -367,9 +378,49 @@ class SchemaParser:
             items = []
             for any_ref_item in data['anyOf']:
                 ref = any_ref_item.get('$ref', None)
-                resolved_ref = self._ref_resolver.resolve(ref)
-                ref_schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data, from_depth_level=True)
-                items.append(ref_schema)
+                any_ref_any_type = any_ref_item.get('type')
+                if ref:
+                    resolved_ref = self._ref_resolver.resolve(ref)
+                    ref_schema = self.parse_item(resolved_ref.ref_id, resolved_ref.ref_data, from_depth_level=True)
+                    items.append(ref_schema)
+                elif any_ref_any_type in PRIMITIVE_TYPES:
+                    items.append(
+                        models.SchemaObject(
+                            id='',
+                            type=models.Type(any_ref_any_type),
+                            enum=None,
+                            properties=[],
+                            title=None,
+                            format=None,
+                            items=None,
+                            required=None,
+                        )
+                    )
+                elif models.Type(any_ref_any_type) is models.Type.object:
+                    additional_roperties = any_ref_item.get('additionalProperties', False)
+                    if additional_roperties:
+                        item_schema_id = f'{parent_schema_id}Item'
+                        items.append(
+                            models.SchemaObject(
+                                id=item_schema_id,
+                                type=models.Type.object,
+                                enum=None,
+                                properties=[],
+                                title=None,
+                                format=None,
+                                items=None,
+                                required=None,
+                                additional_roperties=True,
+                            )
+                        )
+                elif models.Type(any_ref_any_type) is models.Type.array:
+                    schema_id = f'<inline+{models.SchemaObject.__name__}>'
+                    schema = self.parse_item(schema_id, any_ref_item)
+                    items.append(schema)
+                else:
+                    schema_id = f'<inline+{models.SchemaObject.__name__}>'
+                    schema = self.parse_item(schema_id, any_ref_item)  # type: ignore
+                    self._inline_schema_aggregator.add(schema_id, schema)
             return items
 
         return None
