@@ -2,18 +2,16 @@
 Responsible for rendering/generating client code from data
 that was parsed from an OpenAPI file.
 """
-
-
 import logging
+import re
 from dataclasses import dataclass
-from typing import Dict
 from typing import Generic
-from typing import List
-from typing import Optional
-from typing import Tuple
 from typing import TypeVar
 
+import autoflake
+import black
 import inflection
+import isort
 from jinja2 import Environment
 from jinja2 import FileSystemLoader
 
@@ -27,7 +25,16 @@ PathStr = TypeVar('PathStr', bound=str)
 logger = logging.getLogger(__name__)
 
 
-def render_client(*, output_path: str, document: models.Document, name: str, sync: bool, metrics: bool) -> None:
+def render_client(
+    *,
+    output_path: str,
+    document: models.Document,
+    name: str,
+    sync: bool,
+    metrics: bool,
+    pythogen_version: str,
+    required_headers: list[str] | None = None,
+) -> None:
     """Отрисовывает сгенерированный клиент на основе j2-шаблонов
 
     Arguments
@@ -37,7 +44,9 @@ def render_client(*, output_path: str, document: models.Document, name: str, syn
     document
         Спаршенный в python-объекты OpenApi-файл
     """
-    env = Environment(loader=FileSystemLoader(settings.TEMPLATES_DIR_PATH), extensions=['jinja2.ext.loopcontrols'])
+    env = Environment(
+        loader=FileSystemLoader(settings.HTTP_CLIENT_TEMPLATES_DIR_PATH), extensions=['jinja2.ext.loopcontrols']
+    )
     template = env.get_template(
         settings.CLIENT_TEMPLATE_NAME,
         globals={
@@ -46,6 +55,7 @@ def render_client(*, output_path: str, document: models.Document, name: str, syn
             'typerepr': j2_typerepr,
             'responserepr': j2_responserepr,
             'iterresponsemap': iterresponsemap,
+            'parameterfield': parameterfield,
         },
     )
 
@@ -55,6 +65,7 @@ def render_client(*, output_path: str, document: models.Document, name: str, syn
         document=document,
         name=name,
         version=document.info.version,
+        enums=document.sorted_enums,
         models=document.sorted_schemas,
         get=prepared_operations.get,
         post=prepared_operations.post,
@@ -65,6 +76,21 @@ def render_client(*, output_path: str, document: models.Document, name: str, syn
         sync=sync,
         metrics=metrics,
         discriminator_base_class_schemas=document.discriminator_base_class_schemas,
+        required_headers=required_headers,
+        operations=prepared_operations.all(),
+        pythogen_version=pythogen_version,
+    )
+    rendered_client = black.format_str(rendered_client, mode=black.Mode(line_length=120))
+    rendered_client = isort.code(
+        rendered_client,
+        force_grid_wrap=2,
+        lines_after_imports=2,
+        force_single_line=True,
+        line_length=120,
+    )
+    rendered_client = autoflake.fix_code(
+        rendered_client,
+        remove_all_unused_imports=True,
     )
     with open(output_path, 'w') as output_file:
         output_file.write(rendered_client)
@@ -72,12 +98,22 @@ def render_client(*, output_path: str, document: models.Document, name: str, syn
 
 @dataclass
 class PreparedOperations(Generic[PathStr]):
-    get: Dict[PathStr, models.OperationObject]
-    post: Dict[PathStr, models.OperationObject]
-    post_no_body: Dict[PathStr, models.OperationObject]
-    put: Dict[PathStr, models.OperationObject]
-    patch: Dict[PathStr, models.OperationObject]
-    delete_no_body: Dict[PathStr, models.OperationObject]
+    get: dict[PathStr, models.OperationObject]
+    post: dict[PathStr, models.OperationObject]
+    post_no_body: dict[PathStr, models.OperationObject]
+    put: dict[PathStr, models.OperationObject]
+    patch: dict[PathStr, models.OperationObject]
+    delete_no_body: dict[PathStr, models.OperationObject]
+
+    def all(self) -> tuple[models.OperationObject, ...]:
+        return (
+            *self.get.values(),
+            *self.post.values(),
+            *self.post_no_body.values(),
+            *self.put.values(),
+            *self.patch.values(),
+            *self.delete_no_body.values(),
+        )
 
 
 def prepare_operations(document: models.Document) -> PreparedOperations:
@@ -108,7 +144,7 @@ def prepare_operations(document: models.Document) -> PreparedOperations:
     return prepared_operations
 
 
-def iterresponsemap(responses: models.ResponsesObject) -> List[Tuple[str, str]]:
+def iterresponsemap(responses: models.ResponsesObject) -> list[tuple[str, str]]:
     mapping = []
 
     for code, response in responses.patterned.items():
@@ -118,7 +154,7 @@ def iterresponsemap(responses: models.ResponsesObject) -> List[Tuple[str, str]]:
             continue
 
         if response.schema.type == models.Type.object:
-            mapper = f'{classname(response.schema.id)}.parse_obj(response.json())'
+            mapper = f'{classname(response.schema.id)}.model_validate(response.json())'
             mapping.append((code, mapper))
             continue
 
@@ -143,7 +179,7 @@ def iterresponsemap(responses: models.ResponsesObject) -> List[Tuple[str, str]]:
 
                 if items.type is models.Type.object:
                     items_class_name = classname(items.id)
-                    mapper = f'[{items_class_name}.parse_obj(item) for item in response.json()]'
+                    mapper = f'[{items_class_name}.model_validate(item) for item in response.json()]'
                     mapping.append((code, mapper))
                     continue
 
@@ -186,85 +222,105 @@ def j2_responserepr(responses: models.ResponsesObject) -> str:
         else:
             types.append(j2_typerepr(response.schema))
 
-    types = list(set(types))
+    types = sorted(list(set(types)))
 
     if not types:
         return 'None'
 
     elif len(types) == 1:
-        return f'Optional[{types[0]}]'
+        return f'{types[0]} | None'
     else:
-        union_args = ', '.join(types)
-        return f'Union[{union_args}]'
+        return ' | '.join(types)
 
 
-def j2_typerepr(schema: models.SchemaObject, document: Optional[models.Document] = None) -> str:
+def j2_typerepr(schema: models.SchemaObject, document: models.Document | None = None) -> str:
     """Represent data type on j2 template"""
-    primitive_type_mapping = {
-        models.Type.integer: 'int',
-        models.Type.number: 'float',
-        models.Type.boolean: 'bool',
-        models.Type.string: 'str',
-    }
-    format_mapping = {
-        models.Format.binary: 'bytes',
-        models.Format.uri: 'HttpUrl',
-        models.Format.date: 'date',
-        models.Format.date_time: 'datetime',
-    }
-
     # TODO: всегда передавать document в функцию
     if document:
         schema = document.schemas.get(schema.id, schema)
 
-    representation = 'Dict'
+    representation = 'dict'
 
-    if schema.type in primitive_type_mapping:
+    if schema.type in PRIMITIVE_TYPE_MAPPING:
         if schema.enum:
-            representation = f'Literal{schema.enum}'
-        elif schema.format in format_mapping:
-            representation = format_mapping[schema.format]  # type: ignore
+            if schema.id == '<inline+SchemaObject>':
+                representation = f'Literal{schema.enum}'
+            else:
+                representation = classname(schema.id)
+        elif schema.format in FORMAT_MAPPING:
+            representation = FORMAT_MAPPING[schema.format]  # type: ignore
         else:
-            representation = primitive_type_mapping[schema.type]
+            representation = PRIMITIVE_TYPE_MAPPING[schema.type]
 
     elif schema.type == models.Type.object and schema.id != '<inline+SchemaObject>':
         representation = classname(schema.id)
 
     elif schema.type == models.Type.array and schema.items:
         if schema.items.type is models.Type.any_of:  # type: ignore
-            class_items = []
-            primitive_items = []
-            for item in schema.items.items:  # type: ignore
-                if item.id:
-                    class_items.append(classname(item.id))
-                else:
-                    primitive_items.append(primitive_type_mapping[item.type])
-
-            class_items_str = ', '.join([f'{class_item}' for class_item in class_items])
-            primitives_items_str = ', '.join(primitive_items)
-
-            items = []
-            if class_items_str:
-                items.append(class_items_str)
-            if primitives_items_str:
-                items.append(primitives_items_str)
-
-            items_str = ', '.join(items)
-            representation = f'List[Union[{items_str}]]'
+            list_items_repr = _repr_any_of_schema(schema.items.items)  # type: ignore
+            representation = f'list[{list_items_repr}]'
         else:
             item = j2_typerepr(schema.items)  # type: ignore
-            representation = f'List[{item}]'
+            representation = f'list[{item}]'
 
-    elif schema.type == models.Type.any_of:
-        representation = classname(schema.id)
+    elif schema.type is models.Type.any_of:
+        representation = _repr_any_of_schema(schema.items)  # type: ignore
 
     return representation
 
 
+def _repr_any_of_schema(any_of_items: list[models.SchemaObject]) -> str:
+    items = []
+    for item in any_of_items:
+        if item.additional_roperties:
+            items.append('dict[Any, Any]')
+        elif item.type is models.Type.array and item.items:
+            repr = j2_typerepr(item)
+            items.append(repr)
+        elif item.id:
+            items.append(classname(item.id))
+        else:
+            if item.type is models.Type.null and not item.required:
+                continue
+            items.append(PRIMITIVE_TYPE_MAPPING[item.type])
+    return ' | '.join(items)
+
+
 def varname(value: str) -> str:
-    return inflection.underscore(value)
+    clean_value = re.sub('\W|^(?=\d)', '_', value)  # remove special characters
+    clean_value = re.sub('_{2,}', '_', clean_value)  # __ -> _
+    clean_value = clean_value.replace(' ', '_')
+    return inflection.underscore(clean_value)
 
 
 def classname(value: str) -> str:
-    value = value.replace('.', '')
-    return inflection.camelize(value)
+    clean_value = re.sub('\W|^(?=\d)', '_', value)  # remove special characters
+    clean_value = re.sub('_{2,}', '_', clean_value)  # __ -> _
+    return inflection.camelize(clean_value)
+
+
+def parameterfield(parameter: models.ParameterObject) -> str:
+    args: list[str] = []
+    if not parameter.required:
+        args.append('None')
+    if parameter.safety_key != parameter.orig_key:
+        args.append(f'alias="{parameter.orig_key}"')
+    if parameter.description:
+        args.append(f'description="{parameter.description}"')
+    return 'Field(' + ', '.join(args) + ')'
+
+
+PRIMITIVE_TYPE_MAPPING = {
+    models.Type.integer: 'int',
+    models.Type.number: 'float',
+    models.Type.boolean: 'bool',
+    models.Type.string: 'str',
+    models.Type.null: 'None',
+}
+
+FORMAT_MAPPING = {
+    models.Format.binary: 'bytes',
+    models.Format.uri: 'HttpUrl',
+    models.Format.date: 'datetime.date',
+    models.Format.datetime: 'datetime.datetime',
+}
